#########################################################################
win32wifi (Python Windows Wifi)
#########################################################################

win32wifi is a set of Python bindings for the Windows Native Wifi API.

The Native Wifi API is designed for C/C++ developers. Programmers should be
familiar with wireless networking concepts and terminology.

Authors
==============

Andres Blanco 	(6e726d)

Shaked Gitelman (almondg)

License
==============

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

References
==============

 - Windows Native Wifi API -- http://msdn.microsoft.com/en-us/library/windows/desktop/ms706556(v=vs.85).aspx